@@ -6,13 +6,13 @@ WWW::Mechanize - Handy web browsing in a Perl object
 
 =head1 VERSION
 
-Version 0.72
+Version 0.74
 
-    $Header: /cvsroot/www-mechanize/www-mechanize/lib/WWW/Mechanize.pm,v 1.103 2004/01/13 04:36:36 petdance Exp $
+    $Header: /cvsroot/www-mechanize/www-mechanize/lib/WWW/Mechanize.pm,v 1.119 2004/03/23 05:22:40 petdance Exp $
 
 =cut
 
-our $VERSION = "0.72";
+our $VERSION = "0.74";
 
 =head1 SYNOPSIS
 
@@ -92,75 +92,6 @@ link if your bug isn't already reported.
 
 =back
 
-=head1 OTHER DOCUMENTATION
-
-=head2 I<Spidering Hacks>, by Kevin Hemenway and Tara Calishain
-
-I<Spidering Hacks> from O'Reilly
-(L<http://www.oreilly.com/catalog/spiderhks/>) is a great book for anyone
-wanting to know more about screen-scraping and spidering.
-
-There are six hacks that use Mech or a Mech derivative:
-
-=over 4
-
-=item #21 WWW::Mechanize 101
-
-=item #22 Scraping with WWW::Mechanize
-
-=item #36 Downloading Images from Webshots
-
-=item #44 Archiving Yahoo! Groups Messages with WWW::Yahoo::Groups
-
-=item #64 Super Author Searching
-
-=item #73 Scraping TV Listings
-
-=back
-
-The book was also positively reviewed on Slashdot: 
-L<http://books.slashdot.org/article.pl?sid=03/12/11/2126256>
-
-=head2 Online resources
-
-=over 4
-
-=item * WWW::Mechanize Development mailing list
-
-Hosted at Sourceforge, this is where the contributors to Mech
-discuss things.  L<http://sourceforge.net/mail/?group_id=83309>
-
-=item * LWP mailing list
-
-The LWP mailing list is at
-L<http://lists.perl.org/showlist.cgi?name=libwww>, and is more
-user-oriented and well-populated than the WWW::Mechanize Development
-list.  This is a good list for Mech users, since LWP is the basis
-for Mech.
-
-=item * L<WWW::Mechanize::Examples>
-
-A random array of examples submitted by users, included with the
-Mechanize distribution.
-
-=item * L<http://www.perl.com/pub/a/2003/01/22/mechanize.html>
-
-Chris Ball's article about using WWW::Mechanize for scraping TV
-listings.
-
-=item * L<http://www.stonehenge.com/merlyn/LinuxMag/col47.html>
-
-Randal Schwartz's article on scraping Yahoo News for images.  It's
-already out of date: He manually walks the list of links hunting
-for matches, which wouldn't have been necessary if the C<find_link()>
-method existed at press time.
-
-=item * L<http://www.perladvent.org/2002/16th/>
-
-WWW::Mechanize on the Perl Advent Calendar, by Mark Fowler.
-
-=back
-
 =cut
 
 use strict;
@@ -178,7 +109,7 @@ our %headers;
 
 =head1 Constructor and startup
 
-=head2 new() 
+=head2 new()
 
 Creates and returns a new WWW::Mechanize object, hereafter referred to as
 the 'agent'.
@@ -284,7 +215,7 @@ sub new {
     return $self;
 }
 
-=head2 $mech->agent_alias( $alias ) 
+=head2 $mech->agent_alias( $alias )
 
 Sets the user agent string to the expanded version from a table of actual user strings.
 I<$alias> can be one of the following:
@@ -350,7 +281,7 @@ sub known_agent_aliases {
 
 =head1 Page-fetching methods
 
-=head2 $mech->get($url) 
+=head2 $mech->get($url)
 
 Given a URL/URI, fetches it.  Returns an L<HTTP::Response> object.
 I<$url> can be a well-formed URL string, or a L<URI> object.
@@ -380,7 +311,7 @@ sub get {
     return $self->SUPER::get( $uri->as_string, @_ );
 }
 
-=head2 $mech->reload() 
+=head2 $mech->reload()
 
 Acts like the reload button in a browser: Reperforms the current
 request.
@@ -398,7 +329,7 @@ sub reload {
     return $self->request( $self->{req} );
 }
 
-=head2 $mech->back() 
+=head2 $mech->back()
 
 The equivalent of hitting the "back" button in a browser.  Returns to
 the previous page.  Won't go back past the first page. (Really, what
@@ -413,7 +344,7 @@ sub back {
 
 =head1 Link-following methods
 
-=head2 $mech->follow_link(...) 
+=head2 $mech->follow_link(...)
 
 Follows a specified link on the page.  You specify the match to be
 found using the same parms that C<L<find_link()>> uses.
@@ -469,7 +400,7 @@ sub follow_link {
 
 =head1 Form field filling methods
 
-=head2 $mech->form_number($number) 
+=head2 $mech->form_number($number)
 
 Selects the I<number>th form on the page as the target for subsequent
 calls to C<L<field()>> and C<L<click()>>.  Also returns the form that was
@@ -490,7 +421,7 @@ sub form_number {
     }
 }
 
-=head2 $mech->form_name($name) 
+=head2 $mech->form_name($name)
 
 Selects a form by name.  If there is more than one form on the page
 with that name, then the first one is used, and a warning is
@@ -516,7 +447,9 @@ sub form_name {
     }
 }
 
-=head2 $mech->field($name, $value, $number) 
+=head2 $mech->field( $name, $value, $number )
+
+=head2 $mech->field( $name, \@values, $number )
 
 Given the name of a field, set its value to the value specified.  This
 applies to the current form (as set by the C<L<form()>> method or defaulting
@@ -535,11 +468,15 @@ sub field {
     if ($number > 1) {
         $form->find_input($name, undef, $number)->value($value);
     } else {
-        $form->value($name => $value);
+        if ( ref($value) eq "ARRAY" ) {
+            $form->param($name, $value);
+        } else {
+            $form->value($name => $value);
+        }
     }
 }
 
-=head2 $mech->set_fields( $name => $value ... ) 
+=head2 $mech->set_fields( $name => $value ... )
 
 This method sets multiple fields of a form. It takes a list of field
 name and value pairs. If there is more than one field with the same
@@ -638,7 +575,7 @@ sub set_visible {
 
 } # set_visible()
 
-=head2 $mech->tick( $name, $value [, $set] ) 
+=head2 $mech->tick( $name, $value [, $set] )
 
 'Ticks' the first checkbox that has both the name and value assoicated
 with it on the current form.  Dies if there is no named check box for
@@ -674,7 +611,7 @@ sub tick {
     $self->warn( qq{No checkbox "$name" for value "$value" in form} );
 } # tick()
 
-=head2 $mech->untick($name, $value) 
+=head2 $mech->untick($name, $value)
 
 Causes the checkbox to be unticked.  Shorthand for
 C<tick($name,$value,undef)>
@@ -687,7 +624,7 @@ sub untick {
 
 =head1 Form submission methods
 
-=head2 $mech->click( $button [, $x, $y] ) 
+=head2 $mech->click( $button [, $x, $y] )
 
 Has the effect of clicking a button on a form.  The first argument
 is the name of the button to be clicked.  The second and third
@@ -708,7 +645,104 @@ sub click {
     return $self->request( $request );
 }
 
-=head2 $mech->submit() 
+=head2 $mech->click_button( ... ) 
+
+Has the effect of clicking a button on a form by specifying its name,
+value, or index.  Its arguments are a list of key/value pairs.  Only
+one of name, number, or value must be specified.
+
+TODO: This function has no tests.
+
+=over 4
+
+=item * name => name
+
+Clicks the button named I<name>.
+
+=item * number => n
+
+Clicks the I<n>th button in the form.
+
+=item * value => value
+
+Clicks the button with the value I<value>.
+
+=item * x => x
+=item * y => y
+
+These arguments (optional) allow you to specify the (x,y) coordinates
+of the click.
+
+=back
+
+=cut
+
+sub click_button {
+    my $self = shift;
+    my %args = @_;
+
+    for ( keys %args ) {
+        if ( !/^(number|name|value|x|y)$/ ) {
+            $self->warn( qq{Unknown click_button_form parameter "$_"} );
+        }
+    }
+
+    for ($args{x}, $args{y}) { $_ = 1 unless defined; }
+    my $form = $self->{form};
+    my $request;
+    if ( $args{name} ) {
+        $request = $form->click( $args{name}, $args{x}, $args{y} );
+    } elsif ( $args{number} ) {
+        my $input = $form->find_input( undef, 'submit', $args{number} );
+        $request = $input->click( $form, $args{x}, $args{y} );
+    } elsif ( $args{value} ) {
+        my $i = 1;
+        while ( my $input = $form->find_input(undef, 'submit', $i) ) {
+            if ( $args{value} && ($args{value} eq $input->value) ) {
+                $request = $input->click( $form, $args{x}, $args{y} );
+                last;
+            }
+            $i++;
+        } # while
+    } # $args{value}
+
+    return $self->request( $request );
+}
+
+=head2 $mech->select($name, $value) 
+
+=head2 $mech->select($name, \@values) 
+
+Given the name of a C<select> field, set its value to the value
+specified.  If the field is not E<lt>select multipleE<gt> and the
+C<$value> is an array, only the last value will be set.  This applies
+to the current form (as set by the C<L<form()>> method or defaulting
+to the first form on the page).
+
+=cut
+
+sub select {
+    my ($self, $name, $value) = @_;
+
+    my $form = $self->{form};
+
+    my $input = $form->find_input($name);
+    if (!$input) {
+        $self->warn( qq{ Input "$name" not found } );
+        return;
+    } elsif ($input->type ne 'option') {
+        $self->warn( qq{ Input "$name" is not type "select" } );
+        return;
+    }
+
+    if (ref($value) eq "ARRAY") {
+        $form->param($name, $value);
+    } else {
+        $form->value($name => $value);
+    }
+}
+
+=head2 $mech->submit()
 
 Submits the page, without specifying a button to click.  Actually,
 no button is clicked at all.
@@ -725,7 +759,7 @@ sub submit {
     return $self->request( $request );
 }
 
-=head2 $mech->submit_form( ... ) 
+=head2 $mech->submit_form( ... )
 
 This method lets you select a form from the previously fetched page,
 fill in its fields, and submit it. It combines the form_number/form_name,
@@ -799,7 +833,7 @@ sub submit_form {
 
 =head1 Status methods
 
-=head2 $mech->success() 
+=head2 $mech->success()
 
 Returns a boolean telling whether the last request was successful.
 If there hasn't been an operation yet, returns false.
@@ -815,51 +849,51 @@ sub success {
 }
 
 
-=head2 $mech->uri() 
+=head2 $mech->uri()
 
 Returns the current URI.
 
-=head2 $mech->response() / $mech->res() 
+=head2 $mech->response() / $mech->res()
 
 Return the current response as an L<HTTP::Response> object.
 
 Synonym for C<< $mech->response() >>
 
-=head2 $mech->status() 
+=head2 $mech->status()
 
 Returns the HTTP status code of the response.
 
-=head2 $mech->ct() 
+=head2 $mech->ct()
 
 Returns the content type of the response.
 
-=head2 $mech->base() 
+=head2 $mech->base()
 
 Returns the base URI for the current response
 
-=head2 $mech->content() 
+=head2 $mech->content()
 
 Returns the content for the response
 
-=head2 $mech->forms() 
+=head2 $mech->forms()
 
 When called in a list context, returns a list of the forms found in
 the last fetched page. In a scalar context, returns a reference to
 an array with those forms. The forms returned are all L<HTML::Form>
 objects.
 
-=head2 $mech->current_form() 
+=head2 $mech->current_form()
 
 Returns the current form as an L<HTML::Form> object.  I'd call this
 C<form()> except that C<L<form()>> already exists and sets the current_form.
 
-=head2 $mech->links() 
+=head2 $mech->links()
 
 When called in a list context, returns a list of the links found in the
 last fetched page.  In a scalar context it returns a reference to an array
 with those links.  Each link is a L<WWW::Mechanize::Link> object.
 
-=head2 $mech->is_html() 
+=head2 $mech->is_html()
 
 Returns true/false on whether our content is HTML, according to the
 HTTP headers.
@@ -889,7 +923,7 @@ sub forms {
 }
 
 
-=head2 $mech->title() 
+=head2 $mech->title()
 
 Returns the contents of the C<< <TITLE> >> tag, as parsed by
 L<HTML::HeadParser>.  Returns undef if the content is not HTML.
@@ -908,7 +942,7 @@ sub title {
 
 =head1 Content-handling methods
 
-=head2 $mech->find_link() 
+=head2 $mech->find_link()
 
 This method finds a link in the currently fetched page. It returns a
 L<WWW::Mechanize::Link> object which describes the link.  (You'll probably
@@ -946,6 +980,14 @@ leading or trailing spaces will fail.
 =item * C<< url => string >> and C<< url_regex => regex >>
 
 Matches the URL of the link against I<string> or I<regex>, as appropriate.
+The URL may be a relative URL, like F<foo/bar.html>, depending on how
+it's coded on the page.
+
+=item * C<< url_abs => string >> and C<< url_abs_regex => regex >>
+
+Matches the absolute URL of the link against I<string> or I<regex>,
+as appropriate.  The URL will be an absolute URL, even if it's relative
+in the page.
 
 =item * C<< name => string >> and C<< name_regex => regex >>
 
@@ -983,8 +1025,8 @@ text of "News" and with "cnn.com" in the URL, use:
 =head2 $mech->find_link() : link format
 
 The return value is a reference to an array containing
-a L<WWW::Mechanize::Link> object for every link in 
-C<< $self->content >>.  
+a L<WWW::Mechanize::Link> object for every link in
+C<< $self->content >>.
 
 The links come from the following:
 
@@ -1010,7 +1052,7 @@ sub find_link {
 
     for my $key ( keys %parms ) {
         my $val = $parms{$key};
-        if ( $key !~ /^(n|(text|url|name|tag)(_regex)?)$/ ) {
+        if ( $key !~ /^(n|(text|url|url_abs|name|tag)(_regex)?)$/ ) {
             $self->warn( qq{Unknown link-finding parameter "$key"} );
             delete $parms{$key};
             next;
@@ -1022,18 +1064,18 @@ sub find_link {
             next;
         }
 
-	if ($key !~ /_regex$/) {
-	    if (ref($val) eq "Regexp") {
-		$self->warn( qq{$val passed as '$key' is a regex} );
-		delete $parms{$key};
-		next;
-	    }
-	    if ($val =~ /^\s|\s$/) {
-		$self->warn( qq{'$val' is space-padded and cannot succeed} );
-		delete $parms{$key};
-		next;
-	    }
-	}
+        if ($key !~ /_regex$/) {
+            if (ref($val) eq "Regexp") {
+                $self->warn( qq{$val passed as '$key' is a regex} );
+                delete $parms{$key};
+                next;
+            }
+            if ($val =~ /^\s|\s$/) {
+                $self->warn( qq{'$val' is space-padded and cannot succeed} );
+                delete $parms{$key};
+                next;
+            }
+        }
     } # for keys %parms
 
     my @links = $self->links or return;
@@ -1041,6 +1083,8 @@ sub find_link {
     my @conditions;
     push @conditions, q/ $_[0]->[0] eq $parms{url} /                                if defined $parms{url};
     push @conditions, q/ $_[0]->[0] =~ $parms{url_regex} /                          if defined $parms{url_regex};
+    push @conditions, q/ $_[0]->url_abs eq $parms{url_abs} /                        if defined $parms{url_abs};
+    push @conditions, q/ $_[0]->url_abs =~ $parms{url_abs_regex} /                  if defined $parms{url_abs_regex};
     push @conditions, q/ defined($_[0]->[1]) and $_[0]->[1] eq $parms{text} /       if defined $parms{text};
     push @conditions, q/ defined($_[0]->[1]) and $_[0]->[1] =~ $parms{text_regex} / if defined $parms{text_regex};
     push @conditions, q/ defined($_[0]->[2]) and $_[0]->[2] eq $parms{name} /       if defined $parms{name};
@@ -1077,7 +1121,7 @@ sub find_link {
     return;
 } # find_link
 
-=head2 $mech->find_all_links( ... ) 
+=head2 $mech->find_all_links( ... )
 
 Returns all the links on the current page that match the criteria.  The
 method for specifying link criteria is the same as in C<L<find_link()>>.
@@ -1099,7 +1143,7 @@ sub find_all_links {
 
 =head1 Miscellaneous methods
 
-=head2 $mech->add_header(name => $value) 
+=head2 $mech->add_header(name => $value)
 
 Sets a header for the WWW::Mechanize agent to use every time it gets
 a webpage.  This is B<NOT> stored in the agent object (because if it
@@ -1116,7 +1160,7 @@ sub add_header {
     $WWW::Mechanize::headers{$name} = $value;
 }
 
-=head2 $mech->quiet(true/false) 
+=head2 $mech->quiet(true/false)
 
 Allows you to suppress warnings to the screen.
 
@@ -1136,7 +1180,7 @@ sub quiet {
 
 =head1 Overridden L<LWP::UserAgent> methods
 
-=head2 $mech->redirect_ok() 
+=head2 $mech->redirect_ok()
 
 An overloaded version of C<redirect_ok()> in L<LWP::UserAgent>.
 This method is used to determine whether a redirection in the request
@@ -1158,7 +1202,7 @@ sub redirect_ok {
 }
 
 
-=head2 $mech->request( $request [, $arg [, $size]]) 
+=head2 $mech->request( $request [, $arg [, $size]])
 
 Overloaded version of C<request()> in L<LWP::UserAgent>.  Performs
 the actual request.  Normally, if you're using WWW::Mechanize, it'd
@@ -1184,6 +1228,19 @@ sub request {
     }
     $self->{req} = $request;
     $self->{redirected_uri} = $request->uri->as_string;
+
+    # add correct Accept-Encoding header to restore compliance with
+    # http://www.freesoft.org/CIE/RFC/2068/158.htm
+    unless ($request->header('Accept-Encoding')) {
+        my $accept = 'identity';
+        # only allow "identity" for the time being
+        #eval {
+        #  require Compress::Zlib;
+        #  $accept .= ', deflate, gzip';
+        #};
+        $self->add_header( 'Accept-Encoding', $accept);
+    };
+
     my $res = $self->{res} = $self->_make_request( $request, @_ );
 
     # These internal hash elements should be dropped in favor of
@@ -1192,6 +1249,15 @@ sub request {
     $self->{base}    = $res->base;
     $self->{ct}      = $res->content_type || "";
     $self->{content} = $res->content;
+
+    # decode any gzipped/compressed response
+    # (currently isn't reached because we only allow 'identity')
+    my $encoding = $res->header('Content-Encoding') || "";
+    if ($encoding =~ /^(?:gzip|deflate)$/) {
+        $self->{content} = Compress::Zlib::memGunzip( $self->{content});
+        # should I delete the response header?
+    };
+
     if ( $self->{res}->is_success ) {
         $self->{uri} = $self->{redirected_uri};
         $self->{last_uri} = $self->{uri};
@@ -1207,7 +1273,7 @@ sub request {
     return $res;
 } # request
 
-=head2 $mech->_parse_html() 
+=head2 $mech->_parse_html()
 
 An internal method that initializes forms and links given a HTML document.
 If you need to override this in your subclass, or call it multiple times,
@@ -1223,7 +1289,7 @@ sub _parse_html {
 }
 
 
-=head2 C<_make_request()>
+=head2 $mech->_make_request()
 
 Convenience method to make it easier for subclasses like
 L<WWW::Mechanize::Cached> to intercept the request.
@@ -1240,7 +1306,7 @@ sub _make_request {
 This methods have been replaced by more flexible and precise methods.
 Please use them instead.
 
-=head2 $mech->follow($string|$num) 
+=head2 $mech->follow($string|$num)
 
 B<DEPRECATED> in favor of C<L<follow_link()>>, which provides more
 flexibility.
@@ -1285,7 +1351,7 @@ sub follow {
     return 1;
 }
 
-=head2 $mech->form($number|$name) 
+=head2 $mech->form($number|$name)
 
 B<DEPRECATED> in favor of C<L<form_name()>> or C<L<form_number()>>.
 
@@ -1304,10 +1370,10 @@ sub form {
 
 =head1 Internal-only methods
 
-These methods are only used internally.  You probably don't need to 
+These methods are only used internally.  You probably don't need to
 know about them.
 
-=head2 $mech->_reset_page() 
+=head2 $mech->_reset_page()
 
 Resets the internal fields that track page parsed stuff.
 
@@ -1320,11 +1386,11 @@ sub _reset_page {
     delete $self->{title};
     $self->{forms} = [];
     delete $self->{form};
-    
+
     return;
 }
 
-=head2 $mech->_extract_links() 
+=head2 $mech->_extract_links()
 
 Extracts links from the content of a webpage, and populates the C<{links}>
 property with L<WWW::Mechanize::Link> objects.
@@ -1336,6 +1402,7 @@ my %urltags = (
     area => "href",
     frame => "src",
     iframe => "src",
+    meta => "content",
 );
 
 sub _extract_links {
@@ -1344,7 +1411,7 @@ sub _extract_links {
     my $self = shift;
 
     my $p = HTML::TokeParser->new(\$self->{content});
-    
+
     $self->{links} = [];
 
     while (my $token = $p->get_tag( keys %urltags )) {
@@ -1357,18 +1424,29 @@ sub _extract_links {
             $text = $p->get_trimmed_text("/$tag");
             $text = "" unless defined $text;
 
-	    my $onClick = $token->[1]{onclick};
-	    if ( $onClick && ($onClick =~ /^window\.open\(\s*'([^']+)'/) ) {
-		$url = $1;
-	    }
-        }
+            my $onClick = $token->[1]{onclick};
+            if ( $onClick && ($onClick =~ /^window\.open\(\s*'([^']+)'/) ) {
+                $url = $1;
+            }
+        } # a
         if ( $tag ne "area" ) {
             $name = $token->[1]{name};
         }
+        if ( $tag eq "meta" ) {
+            my $equiv = $token->[1]{"http-equiv"};
+            my $content = $token->[1]{"content"};
+            next unless $equiv && (lc $equiv eq "refresh") && defined $content;
+
+            if ( $content =~ /^\d+\s*;\s*url\s*=\s*(.+)/ ) {
+                $url = $1;
+            } else {
+                undef $url;
+            }
+        } # meta
 
         next unless defined $url;   # probably just a name link or <AREA NOHREF...>
         push( @{$self->{links}}, WWW::Mechanize::Link->new( $url, $text, $name, $tag, $self->base ) );
-    }
+    } # while
 
     # Old extract_links() returned a value.  Carp if someone expects
     # this version to return something.
@@ -1380,10 +1458,10 @@ sub _extract_links {
     return;
 }
 
-=head2 $mech->_push_page_stack() / $mech->_pop_page_stack() 
+=head2 $mech->_push_page_stack() / $mech->_pop_page_stack()
 
 The agent keeps a stack of visited pages, which it can pop when it needs
-to go BACK and so on.  
+to go BACK and so on.
 
 The current page needs to be pushed onto the stack before we get a new
 page, and the stack needs to be popped when BACK occurs.
@@ -1467,21 +1545,87 @@ sub die {
 sub _warn {
     require Carp;
     &Carp::carp; # pass thru
-    return;
 }
 
 # NOT an object method!
 sub _die {
     require Carp;
     &Carp::croak; # pass thru
-    return;
 }
 
-=head1 See Also
+=head1 OTHER DOCUMENTATION
 
-See also L<WWW::Mechanize::Examples> for sample code.
-L<WWW::Mechanize::FormFiller> and L<WWW::Mechanize::Shell> are add-ons
-that turn Mechanize into more of a scripting tool.
+=head2 I<Spidering Hacks>, by Kevin Hemenway and Tara Calishain
+
+I<Spidering Hacks> from O'Reilly
+(L<http://www.oreilly.com/catalog/spiderhks/>) is a great book for anyone
+wanting to know more about screen-scraping and spidering.
+
+There are six hacks that use Mech or a Mech derivative:
+
+=over 4
+
+=item #21 WWW::Mechanize 101
+
+=item #22 Scraping with WWW::Mechanize
+
+=item #36 Downloading Images from Webshots
+
+=item #44 Archiving Yahoo! Groups Messages with WWW::Yahoo::Groups
+
+=item #64 Super Author Searching
+
+=item #73 Scraping TV Listings
+
+=back
+
+The book was also positively reviewed on Slashdot:
+L<http://books.slashdot.org/article.pl?sid=03/12/11/2126256>
+
+=head2 Online resources
+
+=over 4
+
+=item * WWW::Mechanize Development mailing list
+
+Hosted at Sourceforge, this is where the contributors to Mech
+discuss things.  L<http://sourceforge.net/mail/?group_id=83309>
+
+=item * LWP mailing list
+
+The LWP mailing list is at
+L<http://lists.perl.org/showlist.cgi?name=libwww>, and is more
+user-oriented and well-populated than the WWW::Mechanize Development
+list.  This is a good list for Mech users, since LWP is the basis
+for Mech.
+
+=item * L<WWW::Mechanize::Examples>
+
+A random array of examples submitted by users, included with the
+Mechanize distribution.
+
+=item * L<http://www.perl.com/pub/a/2003/01/22/mechanize.html>
+
+Chris Ball's article about using WWW::Mechanize for scraping TV
+listings.
+
+=item * L<http://www.stonehenge.com/merlyn/LinuxMag/col47.html>
+
+Randal Schwartz's article on scraping Yahoo News for images.  It's
+already out of date: He manually walks the list of links hunting
+for matches, which wouldn't have been necessary if the C<find_link()>
+method existed at press time.
+
+=item * L<http://www.perladvent.org/2002/16th/>
+
+WWW::Mechanize on the Perl Advent Calendar, by Mark Fowler.
+
+=item * L<http://www.linux-magazin.de/Artikel/ausgabe/2004/03/perl/perl.html>
+
+Michael Schilli's article on Mech and L<WWW::Mechanize::Shell> for the
+German magazine I<Linux Magazin>.
+
+=back
 
 =head2 Other modules that use Mechanize
 
@@ -1503,6 +1647,10 @@ Here are modules that use or subclass Mechanize.  Let me know of any others:
 
 =item * L<WWW::Mechanize::SpamCop>
 
+=item * L<WWW::Mechanize::Timed>
+
+=item * L<WWW::SourceForge>
+
 =item * L<WWW::Yahoo::Groups>
 
 =back
@@ -1519,7 +1667,7 @@ for Mechanize.  Please check to see if your bug has already been reported.
 
 =head1 Author
 
-Copyright 2003 Andy Lester <andy@petdance.com>
+Copyright 2004 Andy Lester <andy@petdance.com>
 
 Released under the Artistic License.  Based on Kirrily Robert's excellent
 L<WWW::Automate> package.
